Learn R Programming

pivottabler (version 1.2.2)

exportValueAs: Replace the current value with a placeholder during export.

Description

exportValueAs is a utility function that returns either the original value or a replacement placeholder value for export.

Usage

exportValueAs(rawValue, formattedValue, exportOptions,
  blankValue = character(0))

Arguments

rawValue

The raw value to check.

formattedValue

The formatted value to be exported.

exportOptions

A list of options controlling export behaviour.

blankValue

The 'placeholder' value to be exported when skipping the value.

Value

Either the original value or a placeholder value.