The `PivotLatexRenderer` class creates a Latex representation of a pivot table.
R6Class object.
new()Create a new `PivotLatexRenderer` object.
PivotLatexRenderer$new(parentPivot = NULL)
parentPivotThe pivot table that this `PivotLatexRenderer` instance belongs to.
A new `PivotLatexRenderer` object.
clearIsRenderedFlags()An internal method used when rendering a pivot table to Latex Clear the IsRendered flags that exist on the `PivotDataGroup` class.
PivotLatexRenderer$clearIsRenderedFlags()
No return value.
resetVisibleRange()Clears the visible range that has been set, so the next call to `getTableLatex()` will render the whole table.
PivotLatexRenderer$resetVisibleRange()
No return value.
setVisibleRange()Specifies a subset of the pivot table to be rendered, e.g. for use when a pivot table will not fit into a single A4 page.
PivotLatexRenderer$setVisibleRange( fromRow = NULL, toRow = NULL, fromColumn = NULL, toColumn = NULL )
fromRowThe row number to render from.
toRowThe row number to render to.
fromColumnThe column number to render from.
toColumnThe column number to render to.
No return value.
getTableLatex()Generate a Latex representation of the pivot table.
PivotLatexRenderer$getTableLatex( caption = NULL, label = NULL, boldHeadings = FALSE, italicHeadings = FALSE, exportOptions = NULL )
captionThe caption to appear above the table.
labelThe label to use when referring to the table elsewhere in the document
boldHeadingsDefault `FALSE`, specify `TRUE` to render headings in bold.
italicHeadingsDefault `FALSE`, specify `TRUE` to render headings in italic.
exportOptionsA list of additional export options - see the "A1. Appendix" for details.
A character variable containing the Latex representation of the pivot table.
clone()The objects of this class are cloneable with this method.
PivotLatexRenderer$clone(deep = FALSE)
deepWhether to make a deep clone.
# NOT RUN {
# This class should only be created by the pivot table.
# It is not intended to be created outside of the pivot table.
# }
Run the code above in your browser using DataLab