convertPvtTblToBasicTbl: Convert a pivot table to a basic table.
Description
convertPvtTblToBasicTbl is a utility function that converts a pivot
table to a basic table from the basictabler package.
Usage
convertPvtTblToBasicTbl(pvt = NULL, exportOptions = NULL,
compatibility = NULL)
Arguments
pvt
The pivot table to convert.
exportOptions
Options specifying how values are exported.
compatibility
Compatibility options specified when creating the
basictabler table.
Value
a basictabler table.